#
# spec file for package ansible-builder
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%if 0%{?suse_version} < 1550
# Leap15, SLES15
%if %pythons == "python310"
%define ansible_python python310
%define ansible_python_executable python3.10
%define ansible_python_sitelib %python310_sitelib
%endif
%if %pythons == "python311"
%define ansible_python python311
%define ansible_python_executable python3.11
%define ansible_python_sitelib %python311_sitelib
%endif
%else
# Tumbleweed
%define pythons python3
%define ansible_python python3
%define ansible_python_executable python3
%define ansible_python_sitelib %python3_sitelib
%endif

Name:           ansible-builder
Version:        3.1.0
Release:        1.4
Summary:        An Ansible execution environment builder
License:        Apache-2.0
URL:            https://github.com/ansible/ansible-builder
Source:         ansible-builder-%{version}.tar.gz
BuildArch:      noarch
BuildRequires:  git-core
# https://github.com/ansible/ansible-builder/blob/devel/setup.cfg#L41
BuildRequires:  %{ansible_python}-base >= 3.9
BuildRequires:  %{ansible_python}-pip
BuildRequires:  %{ansible_python}-setuptools
BuildRequires:  %{ansible_python}-setuptools_scm
BuildRequires:  %{ansible_python}-wheel
BuildRequires:  ansible-core
BuildRequires:  python-rpm-macros
# https://github.com/ansible/ansible-builder/blob/devel/requirements.txt
BuildRequires:  %{ansible_python}-PyYAML
BuildRequires:  %{ansible_python}-bindep
BuildRequires:  %{ansible_python}-filelock
BuildRequires:  %{ansible_python}-jsonschema
BuildRequires:  %{ansible_python}-packaging
BuildRequires:  %{ansible_python}-pbr
#
# Tests require podman, but also require connectivity to pull container images
# hence we do not enable this dependency
# BuildRequires:  podman
#
# SECTION test requirements
# https://github.com/ansible/ansible-builder/blob/devel/test/requirements.txt
BuildRequires:  %{ansible_python}-pytest
BuildRequires:  %{ansible_python}-pytest-mock
BuildRequires:  %{ansible_python}-pytest-xdist
# /SECTION
BuildRequires:  fdupes
Requires:       %{ansible_python}-PyYAML
Requires:       %{ansible_python}-bindep
Requires:       %{ansible_python}-jsonschema
Requires:       %{ansible_python}-packaging
Requires:       (podman or docker)

%description
Ansible Builder is a tool that automates the process of
building execution environments using the schemas and
tooling defined in various Ansible Collections and by
the user.

See the readthedocs page for ansible-builder at:
https://ansible-builder.readthedocs.io/en/latest/

%prep
%setup -q -n ansible-builder-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand sed -i "1{s/env bash/bash/;}" %{buildroot}%{ansible_python_sitelib}/ansible_builder/_target_scripts/entrypoint
%python_expand head -n 1 %{buildroot}%{ansible_python_sitelib}/ansible_builder/_target_scripts/entrypoint
%fdupes %{buildroot}%{ansible_python_sitelib}

%check
# disable coverage tests
sed -i '/cov/d' pytest.ini
# disable color output
sed -i '/color/d' pytest.ini
# add %{buildroot}%{_bindir} to PATH, so the executable is found
export PATH=%{buildroot}%{_bindir}:$PATH
# checks ignored, as they require podman
# https://github.com/ansible/ansible-builder/issues/534
IGNORED_CHECKS="test_v3_pre_post_commands"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_v3_complete"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_ansible_check_is_skipped"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_missing_ansible"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_missing_runner"
%pytest -k "not (${IGNORED_CHECKS})"

%files
%doc README.md
%license LICENSE.md
%{_bindir}/ansible-builder
%{ansible_python_sitelib}/ansible_builder
%{ansible_python_sitelib}/ansible_builder-%{version}.dist-info

%changelog
* Fri Jun 21 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- switch to using a git checkout instead of the PyPI tarball
  without checksum
- update to 3.1.0:
  * New Features
  - Support for tags from the configuration file by @Akasurde in
    [#555]
  - Support multiple -v for verbosity by @Shrews in #564
  - Allow the .yaml file extension on the default EE file by
    @Shrews in #631
  - Account for PEP668 in pip invocations by @Shrews in #627
  - Expose a way to exclude dependencies by @Shrews in #664
  - Support extra build command args by @Shrews in #677
  * Other Improvements
  - Various improvements to documentation.
  - Warn if USER directive is found in additional_build_steps by
    @Akasurde in #528
  - Warn about version less than 3 by @Akasurde in #574
  - Warn user about using default base image in v3 by @Akasurde
    in #591
  - Fix container policy for version 3 by @Shrews in #652
  - Guarantee collection base path exists by @Shrews in #683
* Sat Feb 24 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 3.0.1:
  * Wrap variable in double quotes by @Akasurde in #537
  * definition.rst: Add link to Galaxy requirements file format;
    add example of specifying collection version by @Andersson007
    in #549
  * Docs: mention a few base images as examples, using a free one
    as the default by @felixfontein in #544
  * Update to the builder documentation by @acozine in #552
  * Document PKGMGR_PRESERVE_CACHE by @Akasurde in #558
  * Added scenarios for version 3 by @Akasurde in #538
  * Docs: Using prepend_base by @Akasurde in #563
  * collection_metadata: improve documentation by @Andersson007 in
    [#551]
  * Improve CLI usage docs by @Andersson007 in #559
  * Fix container policy for version 3 by @Shrews in #654
* Fri May 19 2023 Johannes Kastl <kastl@b1-systems.de>
- fix version by BuildRequire for setuptools_scm instead of
  hardcoding the version
* Thu May 18 2023 Johannes Kastl <kastl@b1-systems.de>
- fix 'ansible-builder --version' not reporting the right version
* Mon May 15 2023 Johannes Kastl <kastl@b1-systems.de>
- disable color in checks
* Mon May 15 2023 Johannes Kastl <kastl@b1-systems.de>
- modify %%if-condition to allow building for python3.10 or
  python3.11 on SLES15
* Mon May 15 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 3.0.0:
  * A major evolution of Ansible Builder's Execution Environment
    definition format, with overall themes of increased flexibility
    and minimizing required manual alterations of generated build
    contexts. New features of the version 3 Execution Environment
    definition include:
  - Use of vanilla RHEL-ish container images instead of
    specially-crafted base and builder images (tested against
    Fedora, CentOS Stream 8/9, UBI9 and others).
  - Injection of custom build steps before and after every build
    stage.
  - Copying arbitrary files from the builder host into the
    generated container build context (which can then be copied
    into intermediate/final container images as needed with
    custom build steps).
  - Declarative bootstrapping of Python, Ansible Core, and
    Ansible Runner (in addition to roles/collections, of course).
  - Inline definition of Python/bindep/role/collection
    requirements in Execution Environment YAML (external files
    also still supported).
  - Customization of final container initialization ENTRYPOINT,
    USER, and CMD (with verified automatic defaults).
  - Dynamic builder image from user-specified base image-
    specifying a builder image is no longer required (or
    allowed).
  - Faster builds due to linear stage inheritance and removal of
    forced OS package upgrades.
  - Numerous bugfixes and minor enhancements... see documentation
    for examples.
  * Breaking Changes
  - The `--squash` argument to `build` now defaults to `off` for
    all container runtimes. This allows build caches to function
    by default for `podman` during development and testing, at
    the cost of more intermediate layers in the resultant image.
    Manually specifying `--squash new` is suggested for CI and
    production builds when using `podman` to minimize the size
    and number of intermediate layers.
  - Forced OS package manager upgrades are no longer performed in
    individual build stages by default. If a full OS package
    upgrade is desired, add a new build directive to
    `prepend_base` under `additional_build_steps` (e.g., `- RUN
    dnf upgrade -y`) to upgrade packages on the base image. The
    upgraded packages will be reflected in all subsequent build
    stages.
* Fri May  5 2023 Johannes Kastl <kastl@b1-systems.de>
- change python version on Leap15/SLES15 to python3.11 to use the
  new stack supported by SUSE
* Thu Mar 16 2023 Johannes Kastl <kastl@b1-systems.de>
- new package ansible-builder for building Ansible execution environments
